/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.different;

import java.util.Comparator;
import java.util.List;

/**
 * 差异化比较器，用于比较两个列表之间的变化<br>
 * 
 * @author luoguo
 * 
 * @param <T>
 *            必须要实现Comparable<T>接口，用于进行主键排序，以便根据主键进行排序
 */
public interface Different<T extends Comparable<T>> {
	/**
	 * 设置对象比较器，如果不设置，则用对象自身比较器进行比较，这样就只比较主键了
	 * 
	 * @param comparable
	 */
	void setObjectComparator(Comparator<T> comparator);

	/**
	 * 乱序，可删除，可增加
	 * 
	 * @param collection
	 * @return
	 */
	List<DataWithOperation<T>> different(List<T> collection);

}
